/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Help = function()
{
	var help = {};
	
	/**
		Initialize the page.
	*/
	help.initPage = function()
	{
		var pageId = Doc.getPageId();		
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', help.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', help.validateHelp);
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var clientId = Data.get('page-data', 'client-id');
			var attributes = {'item-type': 'HELP', 'item-id': itemId, 'extra-url': '&client_id='+clientId};
			
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'HELP'};
			var tableAttributes = {'table-id': 'help'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			TabControl.addTabActivateListener('main.properties', help.viewClientProperties);
			
			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}

	help.viewClientProperties = function()
	{
		var frm = document.forms['help'];
		var clientId = frm.client_id.value;
		var url = '../index.jsp?ID='+App.getSessionId();
		url += '&cmd=ViewItem&item_id='+clientId;
		url += '&tab=properties';
		location.replace(url);
	}

	help.validateHelp = function()
	{
		var frm = document.forms['help'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		else if (Strings.trim(frm.external_id.value) == '')
		{
			Forms.showNotification(frm.external_id, 'You must enter an external ID');
			return false;
		}
		return true;
	}

	
	// Submit the form
	help.save = function()
	{
		var frm = document.forms['help'];
		if (TabControl.validateActiveTab('settings'))
		{
			frm.submit();
		}
	}
	
	
	help.initializeToolbarElements = function(element, autoInit)
	{
		if (autoInit == 'enclose-selection')
		{
			Buttons.addClickHandler(element, help.textButtonOnClick);
		}
	}
	
	help.textButtonOnClick = function(event)
	{
		
		/*
			Enclose the selected text with prefix and suffix. Code taken
			from Trac: http://projects.edgewall.com/trac/
		*/
		var prefix = Data.get(event.currentTarget, 'prefix');
		var suffix = Data.get(event.currentTarget, 'suffix');
		
		var frm = document.forms['help'];
		var textarea = frm.description;
		textarea.focus();
	    var start, end, sel, scrollPos, subst;
	    if (typeof(document["selection"]) != "undefined") 
	    {
	      sel = document.selection.createRange().text;
	    } 
	    else if (typeof(textarea["setSelectionRange"]) != "undefined") 
	    {
	      start = textarea.selectionStart;
	      end = textarea.selectionEnd;
	      scrollPos = textarea.scrollTop;
	      sel = textarea.value.substring(start, end);
	    }
	    if (sel.match(/ $/)) 
	    { 
	    	// exclude ending space char, if any
	      	sel = sel.substring(0, sel.length - 1);
	      	suffix = suffix + " ";
	    }
	    subst = prefix + sel + suffix;
	    if (typeof(document["selection"]) != "undefined") 
	    {
	      var range = document.selection.createRange().text = subst;
	      textarea.caretPos -= suffix.length;
	    } 
	    else if (typeof(textarea["setSelectionRange"]) != "undefined") 
	    {
	      textarea.value = textarea.value.substring(0, start) + subst +
	                       textarea.value.substring(end);
	      if (sel) 
	      {
	        textarea.setSelectionRange(start + subst.length, start + subst.length);
	      } 
	      else 
	      {
	        textarea.setSelectionRange(start + prefix.length, start + prefix.length);
	      }
	      textarea.scrollTop = scrollPos;
	    }
	}

	
	return help;
}();

if (Doc.getPageId() == 'edit-page')
{
	Doc.addElementInitializer(Help.initializeToolbarElements);
}
Doc.onLoad(Help.initPage);
