<%-- $Id: view_geometry.jsp 6605 2014-11-18 12:48:42Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.SystemItems"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.PlateGeometry"
	import="net.sf.basedb.core.PlateType"
	import="net.sf.basedb.core.ItemQuery"
	import="net.sf.basedb.core.Include"
	import="net.sf.basedb.core.ItemResultList"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.core.PluginDefinition"
	import="net.sf.basedb.core.plugin.GuiContext"
	import="net.sf.basedb.core.plugin.Plugin"
	import="net.sf.basedb.core.query.Orders"
	import="net.sf.basedb.core.query.Hql"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.PermissionUtil"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.util.formatter.Formatter"
	import="net.sf.basedb.clients.web.formatter.FormatterFactory"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Date"
	import="java.util.Map"
	import="java.util.Set"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="p" uri="/WEB-INF/path.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.PLATEGEOMETRY;
	private static final GuiContext guiContext = new GuiContext(itemType, GuiContext.Type.ITEM);
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	Formatter<Date> dateFormatter = FormatterFactory.getDateFormatter(sc);
	Map<Plugin.MainType, Integer> pluginCount = PluginDefinition.countPlugins(dc, guiContext);

	String title = null;
	PlateGeometry geometry = PlateGeometry.getById(dc, itemId);
	
	final boolean usePermission = geometry.hasPermission(Permission.USE);
	final boolean writePermission = geometry.hasPermission(Permission.WRITE);
	final boolean deletePermission = geometry.hasPermission(Permission.DELETE);
	final boolean sharePermission = geometry.hasPermission(Permission.SET_PERMISSION);
	final boolean isRemoved = geometry.isRemoved();
	final boolean isUsed = isRemoved && geometry.isUsed();
	final boolean deletePermanentlyPermission = deletePermission && !isUsed;
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext, guiContext, geometry);
	ExtensionsInvoker invoker = ToolbarUtil.useExtensions(jspContext);
	%>
	<base:page title="<%=title%>" id="view-page">
	<base:head scripts="table.js,tabcontrol-2.js,~geometries.js" styles="toolbar.css,table.css,headertabcontrol.css,path.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	<base:body>
		<p:path><p:pathelement 
			title="Plate geometries" href="<%="index.jsp?ID="+ID%>" 
			/><p:pathelement title="<%=HTML.encodeTags(geometry.getName())%>" 
			/></p:path>
		<div id="page-data" data-item-id="<%=itemId%>"></div>
		
		<t:tabcontrol 
			id="main" 
			subclass="content mastertabcontrol" 
			active="properties">
		<t:tab id="properties" title="Properties">
			<div>
			<table class="fullform bottomborder">
			<tr>
				<th class="itemstatus">
					<base:icon 
						id="btnDeletePermanently"
						image="deleted.png"
						tooltip="This item has been flagged for deletion. Click to delete it now."
						enabled="<%=deletePermanentlyPermission %>"
						visible="<%=isRemoved%>" 
					/>
					<base:icon
						id="btnUsingItems"
						image="used.png" 
						tooltip="This item is used by other items and can't be permanently deleted. Show the items that are using this one"
						visible="<%=isRemoved && isUsed%>" />
				</th>
				<td style="padding: 0px;">
					<tbl:toolbar subclass="bottomborder bg-filled-50">
						<tbl:button 
							id="btnEdit"
							disabled="<%=!writePermission%>" 
							image="edit.png" 
							title="Edit&hellip;" 
							tooltip="<%=writePermission ? "Edit this plate geometry" : "You do not have permission to edit this plate geometry"%>" 
						/>
						<tbl:button 
							id="btnDelete"
							disabled="<%=!deletePermission%>" 
							image="delete.png" 
							title="Delete"
							visible="<%=!geometry.isRemoved()%>"
							tooltip="<%=deletePermission ? "Delete this plate geometry" : "You do not have permission to delete this plate geometry"%>" 
						/>
						<tbl:button 
							id="btnRestore"
							disabled="<%=!writePermission%>" 
							image="restore.png" 
							title="Restore"
							visible="<%=geometry.isRemoved()%>"
							tooltip="<%=writePermission ? "Restore this plate geometry" : "You do not have permission to restore this plate geometry"%>" 
						/>
						<tbl:button
							id="btnNewPlateType"
							image="add.png"
							title="New plate type&hellip;"
							tooltip="Create a new plate type with this geometry"
							visible="<%=sc.hasPermission(Permission.CREATE, Item.PLATETYPE) && usePermission%>"
						/>
						<tbl:button 
							id="btnImport"
							image="import.png" 
							data-plugin-type="IMPORT"  
							title="Import&hellip;" 
							tooltip="Import data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.IMPORT)%>"
						/>
						<tbl:button 
							id="btnExport"
							image="export.png"
							data-plugin-type="EXPORT" 
							title="Export&hellip;" 
							tooltip="Export data" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.EXPORT)%>"
						/>
						<tbl:button 
							id="btnRunPlugin"
							image="runplugin.png"  
							data-plugin-type="OTHER" 
							title="Run plugin&hellip;" 
							tooltip="Run a plugin" 
							visible="<%=pluginCount.containsKey(Plugin.MainType.OTHER)%>"
						/>
						<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
							wrapper="<%=new PrefixSuffixRenderer(jspContext, "<td>", "</td>") %>"/>
						<tbl:button
							image="help.png"
							subclass="auto-init"
							data-auto-init="help"
							data-help-id="plategeometry.view.properties"
							title="Help&hellip;"
							tooltip="Get help about this page"
						/>
					</tbl:toolbar>
				</td>
			</tr>
			<tr>
				<th>Name</th>
				<td><%=HTML.encodeTags(geometry.getName())%></td>
			</tr>
			<tr>
				<th>Registered</th>
				<td><%=dateFormatter.format(geometry.getEntryDate())%></td>
			</tr>
			<tr>
				<th>Rows</th>
				<td><%=geometry.getRows()%></td>
			</tr>
			<tr>
				<th>Columns</th>
				<td><%=geometry.getColumns()%></td>
			</tr>
			<tr>
				<th>Permissions</th>
				<td><%=PermissionUtil.getFullPermissionNames(geometry)%></td>
			</tr>
			<tr>
				<th>Description</th>
				<td><%=HTML.niceFormat(geometry.getDescription())%></td>
			</tr>
			</table>
			</div>

			<%
			ItemQuery<PlateType> plateTypeQuery = geometry.getPlateTypes();
			plateTypeQuery.include(Include.ALL);
			plateTypeQuery.order(Orders.asc(Hql.property("name")));
			ItemResultList<PlateType> plateTypes = plateTypeQuery.list(dc);
			%>
			<base:section 
				id="types" 
				title="<%="Plate types (" + plateTypes.size() + ")"%>"
				context="<%=cc%>"
				>
				<%
				if (plateTypes.size() == 0)
				{
					%>
					<div class="messagecontainer note">
					No plate types have this geometry
					(or, you don't have permission to view them).
					</div>
					<%
				}
				else
				{
					%>
					<tbl:table
						id="plateTypes"
						columns="all"
						>
					<tbl:columndef 
						id="name"
						title="Name"
					/>
					<tbl:columndef 
						id="description"
						title="Description"
					/>
					<tbl:data>
						<tbl:headers>
							<tbl:headerrow>
								<tbl:columnheaders />
							</tbl:headerrow>
						</tbl:headers>
						<tbl:rows>
						<%
						for (PlateType item : plateTypes)
						{
							%>
							<tbl:row>
								<tbl:cell column="name"><base:icon 
										image="deleted.png" 
										tooltip="This item has been scheduled for deletion" 
										visible="<%=item.isRemoved()%>"
									/><%=Base.getLinkedName(ID, item, false, true)%></tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(item.getDescription())%></tbl:cell>
							</tbl:row>
							<%
						}
						%>
						</tbl:rows>
					</tbl:data>
					</tbl:table>
					<%
				}
				%>
			</base:section>
			<jsp:include page="../../common/anytoany/list_anytoany.jsp">
				<jsp:param name="ID" value="<%=ID%>" />
				<jsp:param name="item_type" value="<%=itemType.name()%>" />
				<jsp:param name="item_id" value="<%=itemId%>" />
				<jsp:param name="title" value="Other items related to this geometry" />
			</jsp:include>
		</t:tab>
		</t:tabcontrol>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}

%>
